/////////////////////////////////////////////////////////////////////////////////////////
// Jocopod -- Joystick to Control Port Dongle
//            --          --      --   -
//
// (c) 2015-2016, Oliver "lvr" Tscherwitschke
// lvr@bitbang.de
//
// This file is part of the Jocopod Firmware.
//
// The Jocopod Firmware is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// The Jocopod Firmware is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Jocopod Firmware. If not, see <http://www.gnu.org/licenses/>.
/////////////////////////////////////////////////////////////////////////////////////////

#include "util.h"



// Convert joystick position 'x' to a paddle value [axis.pot.min .. axis.pot.max]
int joyToPaddle(int x, Axis& axis)
{
    int p;
    
    if (x >= axis.joy.mid)
    {
        p = (long) (x - axis.joy.mid) * (axis.pot.max - axis.pot.mid) / (axis.joy.max - axis.joy.mid) + axis.pot.mid;
        p = min(p, axis.pot.max);
    }
    else
    {
        p = (long) (x - axis.joy.mid) * (axis.pot.min - axis.pot.mid) / (axis.joy.min - axis.joy.mid) + axis.pot.mid;
        p = max(p, axis.pot.min);
    }

    if (axis.invert)
        p = axis.pot.max - p;     // invert
    
    return p;
}


// Convert paddle value [0..255] to OCR register value
uint16_t paddleToOCR(int x)
{
    return (3872 + (x << 4) + (x /*>> 1*/)) / F_CPU_DIV;
}


// Return true if time 't' [ms] has expired.
bool timeExpired(unsigned long t)
{
    unsigned long now = millis();
    long diff = now - t;

    if (diff >= 0)
        return true;

   return false;
}


void printCalib()
{
    Serial.print("X Joy: min:");
    Serial.print(axisX.joy.min);
    Serial.print(" mid:");
    Serial.print(axisX.joy.mid);
    Serial.print(" max:");
    Serial.println(axisX.joy.max);

    Serial.print("  Pot: min:");
    Serial.print(axisX.pot.min);
    Serial.print(" mid:");
    Serial.print(axisX.pot.mid);
    Serial.print(" max:");
    Serial.println(axisX.pot.max);

    Serial.print("Y Joy: min:");
    Serial.print(axisY.joy.min);
    Serial.print(" mid:");
    Serial.print(axisY.joy.mid);
    Serial.print(" max:");
    Serial.println(axisY.joy.max);

    Serial.print("  Pot: min:");
    Serial.print(axisY.pot.min);
    Serial.print(" mid:");
    Serial.print(axisY.pot.mid);
    Serial.print(" max:");
    Serial.println(axisY.pot.max);

}

